// src/types/SpendCommand/SpendCommand.ts
var spendingCommands = ["/spend", "/spend_time"];
var spendCommandPattern = new RegExp(`^(${spendingCommands.join("|")})$`);

// src/types/TimeUnit/TimeUnit.ts
var orderedTimeUnits = ["y", "mo", "w", "d", "h", "m"];

// src/types/TimeValue/TimeValue.ts
var maxValueByTimeUnit = {
  y: 99,
  mo: 11,
  w: 4,
  d: 6,
  h: 23,
  m: 59
};
var timeValuePattern = new RegExp(`^(\\d{1,2})(${orderedTimeUnits.join("|")})$`);
function isTimeValue(value) {
  return timeValuePattern.test(value);
}

// src/utils/validateCommitMsg/validateCommitMsg.ts
var validateCommitMsg = (parsed, when) => {
  if (when === "never") {
    return [true, undefined];
  }
  const { body } = parsed;
  if (!body) {
    return [
      false,
      "Commit message must contain a body (with a spend directive)"
    ];
  }
  const lines = body.split(`
`);
  const spendLines = lines.filter((line) => spendingCommands.some((cmd) => line.startsWith(cmd)));
  if (spendLines.length !== 1 || !spendLines[0]) {
    return [
      false,
      `Commit message body must contain a single spend directive, i.e., one of the following: ${spendingCommands.join(", ")}. Found ${spendLines.length} spend directives.`
    ];
  }
  const spendLine = spendLines[0];
  const spendLineSplit = spendLine.split(" ");
  if (spendLineSplit.length < 2) {
    return [
      false,
      `Spend directive must contain at least one time value. A time value must follow the RegEx pattern: ${timeValuePattern.source}`
    ];
  }
  const maybeTimeValues = spendLineSplit.slice(1);
  const timeValues = [];
  for (let i = 0;i < maybeTimeValues.length; i++) {
    const maybeTimeValue = maybeTimeValues[i];
    if (!isTimeValue(maybeTimeValue)) {
      return [
        false,
        `The time value "${maybeTimeValue}" is not a valid time value. A time value must follow the RegEx pattern: ${timeValuePattern.source}`
      ];
    }
    timeValues.push(maybeTimeValue);
  }
  const unsortedTimeUnits = [];
  for (const timeValue of timeValues) {
    const numericPart = /^(\d+)/.exec(timeValue)?.[1];
    const absoluteNumericValue = Math.abs(parseInt(numericPart, 10));
    const unitPart = timeValue.replace(numericPart, "");
    if (absoluteNumericValue > maxValueByTimeUnit[unitPart]) {
      return [
        false,
        `The time value "${timeValue}" exceeds the maximum value for "${unitPart}" (max value: ${maxValueByTimeUnit[unitPart]})`
      ];
    }
    unsortedTimeUnits.push(unitPart);
  }
  const uniqueTimeUnits = new Set(unsortedTimeUnits);
  if (uniqueTimeUnits.size !== unsortedTimeUnits.length) {
    return [
      false,
      `Duplicate time units found in the spend directive: ${[
        ...unsortedTimeUnits
      ].join(", ")}`
    ];
  }
  const unitIndices = unsortedTimeUnits.map((unit) => orderedTimeUnits.indexOf(unit));
  const isEveryPreviousIndexLarger = unitIndices.every((index, i) => i === 0 || index >= unitIndices[i - 1]);
  if (!isEveryPreviousIndexLarger) {
    return [
      false,
      `Time values are not in the correct order. Time values must be ordered from largest to smallest unit: ${orderedTimeUnits.join(", ")}. Found: ${unsortedTimeUnits.join(", ")}`
    ];
  }
  return [true, undefined];
};

// index.ts
var commitlint_plugin_spend_default = {
  rules: {
    spend: validateCommitMsg
  }
};
export {
  commitlint_plugin_spend_default as default
};
